@@ -19,7 +19,7 @@ sub new_from_file {
     my $class = shift;
     my $file = shift;
     my $self = $class->new({ file => $file });
-    print "Adding $file\n";
+    #print "Adding $file\n";
 
     my @stat = stat $file;
     my $info = Image::Info::image_info( $file );
@@ -42,7 +42,6 @@ sub dpap_hires {
     scalar slurp $self->file;
 }
 
-
 sub dpap_thumb {
     my $self = shift;
     my $image = Image::Imlib2->load( $self->file );
